FastOnboardingPremiumUser class

Inheritance

Constructors

FastOnboardingPremiumUser({Key? key, String? premiumProductId, double? handsetIconSize, double? tabletIconSize, String? descriptionText, String? introText, VoidCallback? onActionTap, FastOnboardingViewController? controller, String? actionText, String? titleText, List<Widget>? children, FastPaletteScheme? palette, String? notesText, Widget? icon})
const

Properties

actionText String?
The text to display as an action.
final
children List<Widget>?
final
controller → FastOnboardingViewController?
The controller to use to pause and resume the onboarding.
final
descriptionText String?
final
handsetIconSize double?
The size of the icon to display on a handset.
final
hashCode int
The hash code for this object.
no setterinherited
icon Widget?
The icon to display at the top of the layout.
final
introText String?
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
notesText String?
final
onActionTap VoidCallback?
The callback to call when the action is tapped.
final
palette → FastPaletteScheme?
The palette to use for the icon.
final
premiumProductId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tabletIconSize double?
The size of the icon to display on a tablet.
final
titleText String?
The title text to display.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FastOnboardingPremiumUser>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited